@@ -249,7 +249,13 @@ class OpenStackConfig(object):
                 config['auth'].pop(opt, None)
 
             if winning_value:
-                config['auth'][p_opt.name.replace('-', '_')] = winning_value
+                # Prefer the plugin configuration dest value if the value's key
+                # is marked as depreciated.
+                if p_opt.dest is None:
+                    config['auth'][p_opt.name.replace('-', '_')] = (
+                        winning_value)
+                else:
+                    config['auth'][p_opt.dest] = winning_value
 
         return config
 
@@ -271,7 +277,7 @@ class OpenStackConfig(object):
 
         args = self._fix_args(kwargs, argparse=argparse)
 
-        if 'region_name' not in args:
+        if 'region_name' not in args or args['region_name'] is None:
             args['region_name'] = self._get_region(cloud)
 
         config = self._get_base_cloud_config(cloud)
